Property Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

M |
| marginBottom, Legend
| marginLeft, Legend
| marginRight, Legend
| marginTop, Legend
| mark $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer
| markerOptions, Series
| markerRenderer $.jqplot.Highlighter$.jqplot.Trendline Series
| markSize $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer
| max $.jqplot.MeterGaugeRenderer Axis
| min $.jqplot.MeterGaugeRenderer Axis
| minorTicks $.jqplot.LinearAxisRenderer$.jqplot.LogAxisRenderer
N |
| name, $.jqplot.CanvasOverlay
| needlePad, $.jqplot.MeterGaugeRenderer
| needleThickness, $.jqplot.MeterGaugeRenderer
| negativeColor, Series
| negativeSeriesColors, jqPlot
| neighborThreshold, Series
| noDataIndicator, jqPlot
| numberColumns Global$.jqplot.DonutLegendRenderer$.jqplot.FunnelLegendRenderer$.jqplot.MekkoLegendRenderer$.jqplot.PieLegendRenderer
| numberRows Global$.jqplot.DonutLegendRenderer$.jqplot.FunnelLegendRenderer$.jqplot.MekkoLegendRenderer$.jqplot.PieLegendRenderer
| numberTicks, Axis
O |
| objects, $.jqplot.CanvasOverlay
| offset, $.jqplot.shadowRenderer
| offsetBars
| openColor, $.jqplot.OHLCRenderer
P |
| pad, Axis
| padding $.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.MeterGaugeRenderer$.jqplot.PieRenderer
| padMax, Axis
| padMin, Axis
| pegNeedle, $.jqplot.MeterGaugeRenderer
| placement, Legend
| position
| predraw, Legend
| prefix $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer
| pt2px $.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer
R |
| renderer $.jqplot.Trendline Axis Grid Series Title
| rendererOptions $.jqplot.Trendline Axis Grid Legend Series Title
| ringColor, $.jqplot.MeterGaugeRenderer
| ringMargin, $.jqplot.DonutRenderer
| ringWidth, $.jqplot.MeterGaugeRenderer
| rowSpacing, Legend

> this.marginBottom = null

CSS margin for the legend DOM element.

> this.marginLeft = null

CSS margin for the legend DOM element.

> this.marginRight = null

CSS margin for the legend DOM element.

> this.marginTop = null

CSS margin for the legend DOM element.

> this.mark = 'outside'

tick mark on the axis.

> this.mark = 'outside'

tick mark on the axis.

> this.markerOptions = {}

renderer specific options to pass to the markerRenderer, see $.jqplot.MarkerRenderer.

> this.markerRenderer = new $.jqplot.MarkerRenderer( | {shadow:false} | )

Renderer used to draw the marker of the highlighted point.

> this.markerRenderer = {show:false}

Renderer to use to draw markers on the line.

> this.markerRenderer = $.jqplot.MarkerRenderer

A class of a renderer which will draw marker (e.g.

> this.markSize = 6

Length of the tick marks in pixels.

> this.markSize = 4

Length of the tick marks in pixels.

> this.max

Maximum value on the gauge.

> this.max = null

maximum value of the axis (in data units, not pixels).

> this.min

Minimum value on the gauge.

> this.min = null

minimum value of the axis (in data units, not pixels).

> this.minorTicks = 0

Number of ticks to add between “major” ticks.

> this.minorTicks = 'auto'

Number of ticks to add between “major” ticks.
Optional name for the overlay object.

> this.needlePad = 6

Padding between needle and inner edge of the ring when the needle is at the min or max gauge value.

> this.needleThickness = null

Maximum thickness the needle.

> this.negativeColor

css color spec used for filled (area) plots that are filled to zero and the “useNegativeColors” option is true.

> this.negativeSeriesColors = $.jqplot.config.defaultNegativeColors

colors to use for portions of the line below zero.

> this.neighborThreshold = 4

how close or far (in pixels) the cursor must be from a point marker to detect the point.

> this.noDataIndicator = { show: false, indicator: 'Loading Data...', axes: { xaxis: { min: 0, max: 10, tickInterval: 2, show: true }, yaxis: { min: 0, max: 12, tickInterval: 3, show: true } } }

Options to set up a mock plot with a data loading indicator if no data is specified.

> this.numberColumns = null

Maximum number of columns in the legend.

> this.numberColumns = null

Maximum number of columns in the legend.

> this.numberColumns = null

Maximum number of columns in the legend.

> this.numberColumns = null

Maximum number of columns in the legend.

> this.numberColumns = null

Maximum number of columns in the legend.

> this.numberRows = null

Maximum number of rows in the legend.

> this.numberRows = null

Maximum number of rows in the legend.

> this.numberRows = null

Maximum number of rows in the legend.

> this.numberRows = null

Maximum number of rows in the legend.

> this.numberRows = null

Maximum number of rows in the legend.

> this.numberTicks

Desired number of ticks.

> this.objects = []

> this.offset = 1

Pixel offset at the given shadow angle of each shadow stroke from the last stroke.

> this.offsetBars = false

False will center bars on their y value.

> this.openColor = null

color of the open price tick mark.

> this.pad = 1.2

Padding to extend the range above and below the data bounds.

> this.padding = 20

padding between the donut and plot edges, legend, etc.

> this.padding = {top: 20, right: 20, bottom: 20, left: 20}

padding between the funnel and plot edges, legend, etc.

> this.padding = null

padding between the meterGauge and plot edges, auto calculated by default.

> this.padding = 20

padding between the pie and plot edges, legend, etc.

> this.padMax = null

Padding to extend the range above data bounds.

> this.padMin = null

Padding to extend the range below data bounds.

> this.pegNeedle = true

True will stop needle just below/above the min/max values if data is below/above min/max, as if the meter is “pegged”.

> this.placement = "insideGrid"

“insideGrid” places legend inside the grid area of the plot.

> this.position = null

Position of axis.
Wether to draw the legend before the series or not.

> this.prefix = ''

String to prepend to the tick label.

> this.prefix = ''

String to prepend to the tick label.

> this.pt2px = null

Point to pixel scaling factor, used for computing height of bounding box around a label.

> this.pt2px = null

Point to pixel scaling factor, used for computing height of bounding box around a label.

> this.renderer = new $.jqplot.LineRenderer()

Renderer to use to draw the trend line.

> this.renderer = $.jqplot.LinearAxisRenderer

A class of a rendering engine that handles tick generation, scaling input data to pixel grid units and drawing the axis element.

> this.renderer = $.jqplot.CanvasGridRenderer

Instance of a renderer which will actually render the grid, see $.jqplot.CanvasGridRenderer.

> this.renderer = $.jqplot.LineRenderer

A class of a renderer which will draw the series, see $.jqplot.LineRenderer.

> this.renderer = $.jqplot.DivTitleRenderer

A class for creating a DOM element for the title, see $.jqplot.DivTitleRenderer.

> this.rendererOptions = {marker:{show:false}}

Options to pass to the line renderer.

> this.rendererOptions = {}

renderer specific options.

> this.rendererOptions = {}

Options to pass on to the renderer, see $.jqplot.CanvasGridRenderer.

> this.rendererOptions = {}

renderer specific options passed to the renderer.

> this.rendererOptions = {}

Options to pass on to the renderer.

> this.rendererOptions = {}

renderer specific options passed to the renderer.

> this.ringColor = "#BBC6D0"

color of the outer ring, hub, and needle of the gauge.

> this.ringMargin = null

pixel distance between rings, or multiple series in a donut plot.

> this.ringWidth = null

width of the ring around the gauge.

> this.rowSpacing = '0.5em'

css padding-top spec for the rows in the legend.
Close